@@ -1,7 +1,7 @@
 /*
  *  Authors: Rodney Dawes <dobey@ximian.com>
  *
- *  Copyright 2004-2006 Novell, Inc. (www.novell.com)
+ *  Copyright 2004-2007 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of version 2 of the GNU General Public License
@@ -239,21 +239,31 @@ gint main (gint argc, gchar ** argv) {
   CORBA_ORB orb;
   GnomeProgram * program;
   GSList * uri_list = NULL;
-  poptContext ctx;
-  const gchar ** args;
-  GValue context = { 0 };
+  GOptionContext *ctx;
+  static gchar **args;
+
+  static GOptionEntry options[] = {
+    { G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_STRING_ARRAY, &args, NULL,  "[URI...]" },
+    { NULL }
+  };
+
+  ctx = g_option_context_new (_("- Evolution webcal: URI Handler"));
 
 #ifdef ENABLE_NLS
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
+  g_option_context_add_main_entries (ctx, options, GETTEXT_PACKAGE);
+#else
+  g_option_context_add_main_entries (ctx, options, NULL);
 #endif
 
   g_thread_init (NULL);
   program = gnome_program_init ("evolution-webcal", VERSION,
 				LIBGNOMEUI_MODULE,
-				argc, argv, GNOME_PARAM_POPT_TABLE,
-				NULL, NULL);
+				argc, argv,
+				GNOME_PARAM_GOPTION_CONTEXT, ctx,
+				NULL);
 
   if (!bonobo_activation_is_initialized ()) {
     orb = bonobo_activation_init (argc, argv);
@@ -261,19 +271,13 @@ gint main (gint argc, gchar ** argv) {
     orb = bonobo_activation_orb_get ();
   }
 
-  g_object_get_property (G_OBJECT (program), GNOME_PARAM_POPT_CONTEXT,
-			 g_value_init (&context, G_TYPE_POINTER));
-  ctx = g_value_get_pointer (&context);
-
-  args = poptGetArgs (ctx);
   if (args != NULL) {
     const gchar ** p;
 
-    for (p = args; *p != NULL; p++) {
+    for (p = (const gchar **) args; *p != NULL; p++) {
       uri_list = g_slist_prepend (uri_list, (char *) *p);
     }
   }
-  poptFreeContext (ctx);
 
   session = soup_session_async_new ();
 
